import { FlatEntity } from '@rest-hooks/core';
import type { FetchOptions, AbstractInstanceType, ReadShape, MutateShape } from '@rest-hooks/core';
import { SchemaDetail, Method, SchemaList } from './types';
import { schemas } from '..';
/** Represents an entity to be retrieved from a server.
 * Typically 1:1 with a url endpoint.
 *
 * This can be a useful organization for many REST-like API patterns.
 */
export default abstract class SimpleResource extends FlatEntity {
    /** Used as base of url construction */
    static readonly urlRoot: string;
    static toString(): string;
    /** Returns the globally unique identifier for this SimpleResource */
    static get key(): string;
    /** Warning level for probable malformed responses
     *
     * We only 'warn' here since this is the upgrade path
     */
    static automaticValidation: "warn";
    /** URL to find this SimpleResource */
    readonly url: string;
    private __url?;
    /** Get the url for a SimpleResource
     *
     * Default implementation conforms to common REST patterns
     */
    static url(urlParams: Readonly<Record<string, any>>): string;
    /** Get the url for many SimpleResources
     *
     * Default implementation conforms to common REST patterns
     */
    static listUrl(searchParams?: Readonly<Record<string, string | number>>): string;
    /** Perform network request and resolve with json body */
    static fetch(method: Method, url: string, body?: Readonly<object | string>): Promise<any>;
    /** Perform network request and resolve with HTTP Response */
    static fetchResponse(method: Method, url: string, body?: Readonly<object | string>): Promise<Response>;
    /** @deprecated */
    /** Get the request options for this SimpleResource  */
    static getFetchOptions(): FetchOptions | undefined;
    /** Init options for fetch - run at fetch */
    static getFetchInit(init: Readonly<RequestInit>): RequestInit;
    /** Get the request options for this SimpleResource  */
    static getEndpointExtra(): FetchOptions | undefined;
    /** Shape to get a single entity */
    static detailShape<T extends typeof SimpleResource>(this: T): ReadShape<SchemaDetail<Readonly<AbstractInstanceType<T>>>>;
    /** Shape to get a list of entities */
    static listShape<T extends typeof SimpleResource>(this: T): ReadShape<SchemaList<Readonly<AbstractInstanceType<T>>>>;
    /** Shape to create a new entity (post) */
    static createShape<T extends typeof SimpleResource>(this: T): MutateShape<SchemaDetail<Readonly<AbstractInstanceType<T>>>, Readonly<object>, Partial<AbstractInstanceType<T>>>;
    /** Shape to update an existing entity (put) */
    static updateShape<T extends typeof SimpleResource>(this: T): MutateShape<SchemaDetail<Readonly<AbstractInstanceType<T>>>, Readonly<object>, Partial<AbstractInstanceType<T>>>;
    /** Shape to update a subset of fields of an existing entity (patch) */
    static partialUpdateShape<T extends typeof SimpleResource>(this: T): MutateShape<SchemaDetail<Readonly<AbstractInstanceType<T>>>, Readonly<object>, Partial<AbstractInstanceType<T>>>;
    /** Shape to delete an entity (delete) */
    static deleteShape<T extends typeof SimpleResource>(this: T): MutateShape<schemas.Delete<T>, Readonly<object>, unknown>;
}
//# sourceMappingURL=SimpleResource.d.ts.map